import Vue from 'vue'
import { uid } from 'quasar'

const state = {
  tasks: {
    /*
    ID1: {
      name: 'Go to shop',
      completed: false,
      dueDate: '2021/03/05',
      dueTime: '18:30'
    },
    ID2: {
      name: 'Get bananas',
      completed: true,
      dueDate: '2021/03/07',
      dueTime: '14:30'
    },
    ID3: {
      name: 'Get apples',
      completed: false,
      dueDate: '2021/03/09',
      dueTime: '16:30'
    }
    */
  },
  search: ''
}

const mutations = {
  updateTask (state, payload) {
    Object.assign(state.tasks[payload.id], payload.updates)
  },
  deleteTask (state, id) {
    Vue.delete(state.tasks, id)
  },
  addTask (state, payload) {
    Vue.set(state.tasks, payload.id, payload.task)
  }
}

const actions = {
  updateTask ({ commit }, payload) {
    commit('updateTask', payload)
  },
  deleteTask ({ commit }, id) {
    commit('deleteTask', id)
  },
  addTask ({ commit }, task) {
    const taskId = uid()
    const payload = {
      id: taskId,
      task: task
    }
    commit('addTask', payload)
  }
}

const getters = {
  tasksTodo: (state) => {
    const tasks = {}
    Object.keys(state.tasks).forEach(function (key) {
      const task = state.tasks[key]
      if (!task.completed) {
        tasks[key] = task
      }
    })
    return tasks
  },
  tasksCompleted: (state) => {
    const tasks = {}
    Object.keys(state.tasks).forEach(function (key) {
      const task = state.tasks[key]
      if (task.completed) {
        tasks[key] = task
      }
    })
    return tasks
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions,
  getters
}
